@@ -1,5 +1,4 @@
-#!/usr/bin/perl
-# Fork.pm 
+# Fork.pm
 # Copyright (c) 2006 Jonathan Rockway <jrockway@cpan.org>
 
 package TestApp::Controller::Fork;
@@ -8,28 +7,28 @@ use strict;
 use warnings;
 use base 'Catalyst::Controller';
 
-eval 'use YAML';
+use JSON::MaybeXS qw(encode_json);
 
 sub system : Local {
     my ($self, $c, $ls) = @_;
     my ($result, $code) = (undef, 1);
 
-    if(!-e $ls || !-x _){ 
+    if(!-e $ls || !-x _){
         $result = 'skip';
     }
     else {
         $result = system($ls, $ls, $ls);
         $result = $! if $result != 0;
     }
-    
-    $c->response->body(Dump({result => $result}));
+
+    $c->response->body(encode_json({result => $result}));
 }
 
 sub backticks : Local {
     my ($self, $c, $ls) = @_;
     my ($result, $code) = (undef, 1);
-    
-    if(!-e $ls || !-x _){ 
+
+    if(!-e $ls || !-x _){
         $result = 'skip';
         $code = 0;
     }
@@ -37,15 +36,15 @@ sub backticks : Local {
         $result = `$ls $ls $ls` || $!;
         $code = $?;
     }
-    
-    $c->response->body(Dump({result => $result, code => $code}));
+
+    $c->response->body(encode_json({result => $result, code => $code}));
 }
 
 sub fork : Local {
     my ($self, $c) = @_;
     my $pid;
     my $x = 0;
-    
+
     if($pid = fork()){
         $x = "ok";
     }
@@ -54,8 +53,8 @@ sub fork : Local {
     }
 
     waitpid $pid,0 or die;
-    
-    $c->response->body(Dump({pid => $pid, result => $x}));
+
+    $c->response->body(encode_json({pid => $pid, result => $x}));
 }
 
 1;
